@@ -3,7 +3,7 @@ import xml.etree.ElementTree as ElementTree
 from .match import Match, Accolade, Entry, Rewards, Team, Player
 from ..exceptions import ParserError
 from ..reward_constants import BOUNTY_CATEGORIES, XP_CATEGORIES, HUNT_DOLLARS_CATEGORY, BLOODBONDS_CATEGORY, \
-    HUNTER_XP_CATEGORY, HUNTER_XP_REWARD_TYPE, HUNTER_LEVELS_CATEGORY, \
+    HUNTER_XP_DESCRIPTOR_NAME, HUNTER_XP_REWARD_TYPE, HUNTER_LEVELS_CATEGORY, \
     UPGRADE_POINTS_DESCRIPTOR_NAME, BLOODLINE_DESCRIPTOR_NAME
 
 
@@ -37,7 +37,8 @@ def _calculate_rewards(accolades: tuple[Accolade, ...], entries: tuple[Entry, ..
     hunt_dollars: int = sum(entry.reward_size for entry in entries if entry.category == HUNT_DOLLARS_CATEGORY)
     bloodbonds: int = sum(entry.reward_size for entry in entries if entry.category == BLOODBONDS_CATEGORY)
     hunter_xp: int = sum(entry.reward_size for entry in entries
-                         if entry.category == HUNTER_XP_CATEGORY and entry.reward_type == HUNTER_XP_REWARD_TYPE)
+                         if entry.descriptor_name == HUNTER_XP_DESCRIPTOR_NAME
+                         and entry.reward_type == HUNTER_XP_REWARD_TYPE)
     hunter_levels: int = sum(entry.reward_size for entry in entries if entry.category == HUNTER_LEVELS_CATEGORY)
     upgrade_points: int = sum(entry.reward_size for entry in entries
                               if entry.descriptor_name == UPGRADE_POINTS_DESCRIPTOR_NAME)
@@ -122,7 +123,6 @@ def _parse_player(root: ElementTree.Element, team_id: int, player_id: int) -> Pl
     downed_me: int = int(_fetch_xpath_value(root, element_prefix, "downedme"))
     downed_teammate: int = int(_fetch_xpath_value(root, element_prefix, "downedteammate"))
     had_wellspring: bool = _fetch_xpath_value(root, element_prefix, "hadWellspring") == "true"
-    had_bounty: bool = _fetch_xpath_value(root, element_prefix, "hadbounty") == "true"
     is_partner: bool = _fetch_xpath_value(root, element_prefix, "ispartner") == "true"
     is_soul_survivor: bool = _fetch_xpath_value(root, element_prefix, "issoulsurvivor") == "true"
     killed_by_me: int = int(_fetch_xpath_value(root, element_prefix, "killedbyme"))
@@ -138,7 +138,7 @@ def _parse_player(root: ElementTree.Element, team_id: int, player_id: int) -> Pl
 
     # Return the player
     return Player(name, bounties_extracted, bounties_picked_up, downed_by_me, downed_by_teammate,
-                  downed_me, downed_teammate, had_wellspring, had_bounty, is_partner, is_soul_survivor,
+                  downed_me, downed_teammate, had_wellspring, is_partner, is_soul_survivor,
                   killed_by_me, killed_by_teammate, killed_me, killed_teammate, mmr, profile_id,
                   proximity_to_me, proximity_to_teammate, skillbased, teamextraction)
 
