@@ -5,11 +5,11 @@ import logging
 from typing import Generator
 from functools import partial
 
-from colorama import Fore, Style, init as colorama_init
+from colorama import Fore, Style, colorama_text
 
-from hunt.constants import HUNT_SHOWDOWN_APP_ID, HUNT_SHOWDOWN_TEST_SERVER_APP_ID, \
+from hunt.constants import RESOURCES_PATH, MATCH_LOGS_PATH, STEAMWORKS_BINARIES_PATH, \
+    HUNT_SHOWDOWN_APP_ID, HUNT_SHOWDOWN_TEST_SERVER_APP_ID, \
     DATABASE_PATH, DATABASE_TEST_SERVER_PATH, STEAMWORKS_SDK_PATH
-from hunt.formats import format_mmr
 from hunt.database.client import Client as DatabaseClient
 from hunt.filesystem.watchdog import FileWatchdog
 from hunt.steam.api import SteamworksApi, fetch_hunt_attributes_path, try_extract_steamworks_binaries
@@ -19,19 +19,55 @@ from hunt.cli.arguments.parser import Config, parse_arguments
 from hunt.cli.exit_codes import ExitCode
 
 
+def setup_logger(config: Config) -> None:
+    """
+    Sets up the application logger.
+    :param config: the configuration provided by the user
+    """
+    # Setup logging
+    logging.basicConfig(format="[%(asctime)s, %(levelname)s] %(message)s",
+                        datefmt="%H:%M", level=logging.INFO if not config.debug else logging.DEBUG,
+                        stream=sys.stdout)
+
+    def setup_level_color(level: int, color: str, padding: int = 8) -> None:
+        """
+        Adjusts a logging level name to add fancy color support.
+        :param level: the logger level
+        :param color: the color to use
+        :param padding: the number of padded whitespace characters
+        """
+        logging.addLevelName(level, f"{color}{logging.getLevelName(level):>{padding}}{Style.RESET_ALL}")
+
+    # Color config
+    color_config: tuple[tuple[int, str], ...] = (
+        (logging.DEBUG, Fore.CYAN),
+        (logging.INFO, Fore.GREEN),
+        (logging.WARNING, Fore.YELLOW),
+        (logging.ERROR, Fore.RED),
+        (logging.CRITICAL, Style.BRIGHT + Fore.RED))
+
+    # Setup the color levels
+    logger_level: int
+    level_color: str
+    for logger_level, level_color in color_config:
+        setup_level_color(logger_level, level_color)
+
+
 def console_main() -> ExitCode:
     """
     The CLI entry point for the package.
     :return: an exit code.
     """
     # Initialize Colorama
-    colorama_init()
+    with colorama_text():
+        # Parse the arguments and forward the app config to main
+        config: Config = parse_arguments()
 
-    # Parse the arguments and forward the app config to main
-    config: Config = parse_arguments()
+        # Setup the logger
+        setup_logger(config)
 
-    # Start the application.
-    return main(config)
+        # Start the application.
+        return main(config)
 
 
 def main(config: Config) -> ExitCode:
@@ -40,10 +76,15 @@ def main(config: Config) -> ExitCode:
     :param config: the configuration provided by the user
     :return: an exit code.
     """
-    # Setup logging
-    logging.basicConfig(format="[%(asctime)s, %(levelname)s] %(message)s",
-                        datefmt="%H:%M", level=logging.INFO if not config.debug else logging.DEBUG,
-                        stream=sys.stdout)
+    try:
+        os.makedirs(name=RESOURCES_PATH, exist_ok=True)  # Create the resource directory if it doesn't exist
+        os.makedirs(name=MATCH_LOGS_PATH, exist_ok=True)  # Create the match logs directory if it doesn't exist
+        os.makedirs(name=STEAMWORKS_BINARIES_PATH, exist_ok=True)  # Create the bin directory if it doesn't exist
+    except OSError as exception:
+        logging.critical("Failed to create create application-critical directories in the current working directory. "
+                         "Are write permissions missing?")
+        logging.debug(f"OS error: {exception=}")
+        return ExitCode.FILESYSTEM_ERROR
 
     try:
         # Extract the Steamworks binaries to disk
@@ -122,7 +163,7 @@ def attributes_file_modified(file_path: str, database: DatabaseClient, steamwork
         parsed_attributes: ElementTree.Element = ElementTree.fromstring(file_contents)
     except ElementTree.ParseError as exception:
         # Skip the update
-        logging.critical("Failed to parse the attributes file.")
+        logging.error("Failed to parse the attributes file.")
         logging.debug(f"Failed to parse the attributes file: {exception=}")
         return
 
@@ -154,10 +195,6 @@ def log_match_data(match: Match) -> None:
     """
     # Log interesting rewards
     def _log_rewards() -> None:
-        # Skip logging if there are no rewards
-        if not match.rewards:
-            return
-
         logging.info("Rewards:")
 
         # Hunt dollars
@@ -181,7 +218,9 @@ def log_match_data(match: Match) -> None:
         # Bloodline XP
         if match.rewards.bloodline_xp:
             logging.info(f"  Collected {match.rewards.bloodline_xp} bloodline XP.")
-    _log_rewards()
+    # Skip logging if there were no rewards
+    if match.rewards:
+        _log_rewards()
 
     # Log players
     def _log_players() -> None:
@@ -193,24 +232,17 @@ def log_match_data(match: Match) -> None:
         # Log information about the local team
         logging.info("Team:")
         player: Player
-        name: str
         for player in teammates:
-            name = f"{Fore.GREEN}{player.name}{Style.RESET_ALL}"
-            local_player_marker: str = " (you)" if player.name == match.player_name else ""
-            logging.info(f"  {name} ({format_mmr(player.mmr)}){local_player_marker}")
+            logging.info(f"  {player.format_name(is_local_player=player.name == match.player_name)}")
 
         # Log information about the players the local player interacted with
         if any(player.killed_by_me or player.killed_me for player in enemies):
             logging.info("Enemies:")
             for player in enemies:
                 if player.killed_by_me:
-                    name = f"{Fore.GREEN}{player.name}{Style.RESET_ALL}"
-                    kill_count: str = f" {player.killed_by_me}x" if player.killed_by_me > 1 else ""
-                    logging.info(f"  Killed {name} ({format_mmr(player.mmr)}){kill_count}")
+                    logging.info(f"  {player.format_kills()}")
                 if player.killed_me:
-                    name = f"{Fore.RED}{player.name}{Style.RESET_ALL}"
-                    death_count: str = f" {player.killed_me}x" if player.killed_me > 1 else ""
-                    logging.info(f"  Died to {name} ({format_mmr(player.mmr)}){death_count}")
+                    logging.info(f"  {player.format_deaths()}")
     _log_players()
 
 
