@@ -7,6 +7,8 @@ from enum import IntEnum, auto as _enum_auto
 class ExitCode(IntEnum):
     # No errors occurred
     SUCCESS: ExitCode = 0  # type: ignore
+    # Filesystem error
+    FILESYSTEM_ERROR: ExitCode = _enum_auto()  # type: ignore
     # Steamworks API related error
     STEAMWORKS_ERROR: ExitCode = _enum_auto()  # type: ignore
     # Unsupported platform
